exceptiontools.OverfullContainerError
=====================================

.. abjad-lineage:: abjad.tools.exceptiontools.OverfullContainerError.OverfullContainerError

.. autoclass:: abjad.tools.exceptiontools.OverfullContainerError.OverfullContainerError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.OverfullContainerError.OverfullContainerError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.OverfullContainerError.OverfullContainerError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.OverfullContainerError.OverfullContainerError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.OverfullContainerError.OverfullContainerError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.OverfullContainerError.OverfullContainerError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.OverfullContainerError.OverfullContainerError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.OverfullContainerError.OverfullContainerError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.OverfullContainerError.OverfullContainerError.__unicode__
   :noindex:
